# ephesus

## Introduction

ephesus is a library for exoplanet science. It provides functions for processing (reading TESS and Kepler data, flattening, phase-folding and plotting) light curves. It can be used to generate synthetic light curves.
